/*
** Module   : ConnectableServer.java
** Abstract : An interface for handles supporting the connect(), disconnect()
**            and connected() attributes for AppServer.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CS  20130321 Created initial version.
** 002 EVL 20130911 Adding legacy attributes and methods annotation.
*/

package com.goldencode.p2j.util;

/**
 * Provides access to the following handler methods.
 * <table>
 * <tr>
 *    <th>attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>CONNECT()</td>
 *    <td>{@link #connect(character, character, character, character)},
 *        {@link #connect(character, character, character)},
 *        {@link #connect(character, character,)}
 *    </td>
 * </tr>
 * </table>
 */
public interface ConnectableServer
extends Connectable
{

   /**
    * Method declaration  for the CONNECT() procedure supported by sockets and
    * web-services.
    *  
    * @param    options
    *           The set of parameters to establish the connect procedure. 4GL allows only  
    *           character values for this parameter.
    * @param    user
    *           The user with which the connection is made.
    * @param    pwd
    *           The password for the user with which the connection is made
    * @param    serverInfo
    *           Server info
    * 
    * @return   <code>true</code> if connection succeeded, or <code>false</code>
    *           otherwise
    */
   @LegacyMethod(name = "CONNECT")
   public logical connect(character options, character user, character pwd, character serverInfo);
   
   /**
    * Method declaration  for the CONNECT() procedure supported by sockets and
    * web-services.
    *  
    * @param    options
    *           The set of parameters to establish the connect procedure. 4GL allows only  
    *           character values for this parameter.
    * @param    user
    *           The user with which the connection is made.
    * @param    pwd
    *           The password for the user with which the connection is made
    * 
    * @return   <code>true</code> if connection succeeded, or <code>false</code>
    *           otherwise
    */
   @LegacyMethod(name = "CONNECT")
   public logical connect(character options, character user, character pwd);
   
   /**
    * Method declaration  for the CONNECT() procedure supported by sockets and
    * web-services.
    *  
    * @param    options
    *           The set of parameters to establish the connect procedure. 4GL allows only  
    *           character values for this parameter.
    * @param    user
    *           The user with which the connection is made.
    * 
    * @return   <code>true</code> if connection succeeded, or <code>false</code>
    *           otherwise
    */
   @LegacyMethod(name = "CONNECT")
   public logical connect(character options, character user);
}
